==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSLoadBalancerParametersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AWSLoadBalancerParametersFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent<A>{
  public AWSLoadBalancerParametersFluentImpl() {
  }
  public AWSLoadBalancerParametersFluentImpl(io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParameters instance) {
    this.withClassicLoadBalancer(instance.getClassicLoadBalancer()); 
    this.withNetworkLoadBalancer(instance.getNetworkLoadBalancer()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder classicLoadBalancer;
  private io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder networkLoadBalancer;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildClassicLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters getClassicLoadBalancer() {
    return this.classicLoadBalancer!=null?this.classicLoadBalancer.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters buildClassicLoadBalancer() {
    return this.classicLoadBalancer!=null?this.classicLoadBalancer.build():null;
  }
  public A withClassicLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters classicLoadBalancer) {
    _visitables.get("classicLoadBalancer").remove(this.classicLoadBalancer);
    if (classicLoadBalancer!=null){ this.classicLoadBalancer= new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder(classicLoadBalancer); _visitables.get("classicLoadBalancer").add(this.classicLoadBalancer);} return (A) this;
  }
  public java.lang.Boolean hasClassicLoadBalancer() {
    return this.classicLoadBalancer != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancer() {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.ClassicLoadBalancerNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.ClassicLoadBalancerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editClassicLoadBalancer() {
    return withNewClassicLoadBalancerLike(getClassicLoadBalancer());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancer() {
    return withNewClassicLoadBalancerLike(getClassicLoadBalancer() != null ? getClassicLoadBalancer(): new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item) {
    return withNewClassicLoadBalancerLike(getClassicLoadBalancer() != null ? getClassicLoadBalancer(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildNetworkLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters getNetworkLoadBalancer() {
    return this.networkLoadBalancer!=null?this.networkLoadBalancer.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters buildNetworkLoadBalancer() {
    return this.networkLoadBalancer!=null?this.networkLoadBalancer.build():null;
  }
  public A withNetworkLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters networkLoadBalancer) {
    _visitables.get("networkLoadBalancer").remove(this.networkLoadBalancer);
    if (networkLoadBalancer!=null){ this.networkLoadBalancer= new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder(networkLoadBalancer); _visitables.get("networkLoadBalancer").add(this.networkLoadBalancer);} return (A) this;
  }
  public java.lang.Boolean hasNetworkLoadBalancer() {
    return this.networkLoadBalancer != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancer() {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.NetworkLoadBalancerNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.NetworkLoadBalancerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editNetworkLoadBalancer() {
    return withNewNetworkLoadBalancerLike(getNetworkLoadBalancer());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancer() {
    return withNewNetworkLoadBalancerLike(getNetworkLoadBalancer() != null ? getNetworkLoadBalancer(): new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item) {
    return withNewNetworkLoadBalancerLike(getNetworkLoadBalancer() != null ? getNetworkLoadBalancer(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AWSLoadBalancerParametersFluentImpl that = (AWSLoadBalancerParametersFluentImpl) o;
    if (classicLoadBalancer != null ? !classicLoadBalancer.equals(that.classicLoadBalancer) :that.classicLoadBalancer != null) return false;
    if (networkLoadBalancer != null ? !networkLoadBalancer.equals(that.networkLoadBalancer) :that.networkLoadBalancer != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(classicLoadBalancer,  networkLoadBalancer,  type,  additionalProperties,  super.hashCode());
  }
  public class ClassicLoadBalancerNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<N>> implements io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ClassicLoadBalancerNestedImpl(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder(this, item);
    }
    ClassicLoadBalancerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder builder;
    public N and() {
      return (N) AWSLoadBalancerParametersFluentImpl.this.withClassicLoadBalancer(builder.build());
    }
    public N endClassicLoadBalancer() {
      return and();
    }
    
  }
  public class NetworkLoadBalancerNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<N>> implements io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    NetworkLoadBalancerNestedImpl(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder(this, item);
    }
    NetworkLoadBalancerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder builder;
    public N and() {
      return (N) AWSLoadBalancerParametersFluentImpl.this.withNetworkLoadBalancer(builder.build());
    }
    public N endNetworkLoadBalancer() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSLoadBalancerParametersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AWSLoadBalancerParametersFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent<A>{
  public AWSLoadBalancerParametersFluentImpl() {
  }
  public AWSLoadBalancerParametersFluentImpl(io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParameters instance) {
    this.withClassicLoadBalancer(instance.getClassicLoadBalancer()); 
    this.withNetworkLoadBalancer(instance.getNetworkLoadBalancer()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder classicLoadBalancer;
  private io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder networkLoadBalancer;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildClassicLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters getClassicLoadBalancer() {
    return this.classicLoadBalancer!=null?this.classicLoadBalancer.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters buildClassicLoadBalancer() {
    return this.classicLoadBalancer!=null?this.classicLoadBalancer.build():null;
  }
  public A withClassicLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters classicLoadBalancer) {
    _visitables.get("classicLoadBalancer").remove(this.classicLoadBalancer);
    if (classicLoadBalancer!=null){ this.classicLoadBalancer= new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder(classicLoadBalancer); _visitables.get("classicLoadBalancer").add(this.classicLoadBalancer);} return (A) this;
  }
  public java.lang.Boolean hasClassicLoadBalancer() {
    return this.classicLoadBalancer != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancer() {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.ClassicLoadBalancerNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.ClassicLoadBalancerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editClassicLoadBalancer() {
    return withNewClassicLoadBalancerLike(getClassicLoadBalancer());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancer() {
    return withNewClassicLoadBalancerLike(getClassicLoadBalancer() != null ? getClassicLoadBalancer(): new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item) {
    return withNewClassicLoadBalancerLike(getClassicLoadBalancer() != null ? getClassicLoadBalancer(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildNetworkLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters getNetworkLoadBalancer() {
    return this.networkLoadBalancer!=null?this.networkLoadBalancer.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters buildNetworkLoadBalancer() {
    return this.networkLoadBalancer!=null?this.networkLoadBalancer.build():null;
  }
  public A withNetworkLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters networkLoadBalancer) {
    _visitables.get("networkLoadBalancer").remove(this.networkLoadBalancer);
    if (networkLoadBalancer!=null){ this.networkLoadBalancer= new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder(networkLoadBalancer); _visitables.get("networkLoadBalancer").add(this.networkLoadBalancer);} return (A) this;
  }
  public java.lang.Boolean hasNetworkLoadBalancer() {
    return this.networkLoadBalancer != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancer() {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.NetworkLoadBalancerNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluentImpl.NetworkLoadBalancerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editNetworkLoadBalancer() {
    return withNewNetworkLoadBalancerLike(getNetworkLoadBalancer());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancer() {
    return withNewNetworkLoadBalancerLike(getNetworkLoadBalancer() != null ? getNetworkLoadBalancer(): new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item) {
    return withNewNetworkLoadBalancerLike(getNetworkLoadBalancer() != null ? getNetworkLoadBalancer(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AWSLoadBalancerParametersFluentImpl that = (AWSLoadBalancerParametersFluentImpl) o;
    if (classicLoadBalancer != null ? !classicLoadBalancer.equals(that.classicLoadBalancer) :that.classicLoadBalancer != null) return false;
    if (networkLoadBalancer != null ? !networkLoadBalancer.equals(that.networkLoadBalancer) :that.networkLoadBalancer != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(classicLoadBalancer,  networkLoadBalancer,  type,  additionalProperties,  super.hashCode());
  }
  public class ClassicLoadBalancerNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<N>> implements io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ClassicLoadBalancerNestedImpl(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder(this, item);
    }
    ClassicLoadBalancerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersBuilder builder;
    public N and() {
      return (N) AWSLoadBalancerParametersFluentImpl.this.withClassicLoadBalancer(builder.build());
    }
    public N endClassicLoadBalancer() {
      return and();
    }
    
  }
  public class NetworkLoadBalancerNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<N>> implements io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    NetworkLoadBalancerNestedImpl(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder(this, item);
    }
    NetworkLoadBalancerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder builder;
    public N and() {
      return (N) AWSLoadBalancerParametersFluentImpl.this.withNetworkLoadBalancer(builder.build());
    }
    public N endNetworkLoadBalancer() {
      return and();
    }
    
  }
  
}
